Module: Ruby
- Defined in:
- lib/ruby/miradore.rb,
lib/ruby/miradore/version.rb
Overview
Ruby::Miradore module
The response will be an array of Ruby::Miradore::Device objects with the attributes of the device.
Ruby::Miradore::Device object is an open struct so you can access the attributes using the dot notation and any
missing method will return nil.
Defined Under Namespace
Modules: Miradore